==> apache-ignite-3.0.0-src.zip: apache-ignite-3.0.0-src/modules/api/src/main/java/org/apache/ignite/table/criteria/Column.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.table.criteria;

import static org.apache.ignite.lang.util.IgniteNameUtils.parseSimpleName;

import org.jetbrains.annotations.Nullable;

/**
 * Represents a column reference for criteria query.
 */
public final class Column implements Criteria {
    private final String name;

    /**
     * Constructor.
     *
     * @param name A column name.
     */
    Column(String name) {
        this.name = parseSimpleName(name);
    }

    /**
     * Gets column name.
     *
     * @return A column name.
     */
    public String getName() {
        return name;
    }

    /** {@inheritDoc} */
    @Override
    public <C> void accept(CriteriaVisitor<C> v, @Nullable C context) {
        v.visit(this, context);
    }
}

==> apache-ignite-3.1.0-src.zip: apache-ignite-3.1.0-src/modules/api/src/main/java/org/apache/ignite/table/criteria/Column.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.table.criteria;

import static org.apache.ignite.lang.util.IgniteNameUtils.parseIdentifier;

import org.jetbrains.annotations.Nullable;

/**
 * Represents a column reference for criteria query.
 */
public final class Column implements Criteria {
    private final String name;

    /**
     * Constructor.
     *
     * @param name A column name.
     */
    Column(String name) {
        this.name = parseIdentifier(name);
    }

    /**
     * Gets column name.
     *
     * @return A column name.
     */
    public String getName() {
        return name;
    }

    /** {@inheritDoc} */
    @Override
    public <C> void accept(CriteriaVisitor<C> v, @Nullable C context) {
        v.visit(this, context);
    }
}
